@@ -89,6 +89,8 @@ class HttpClient(object):
                                                          headers=headers,
                                                          cert=self.cert)
             else:
+                print(cmd_url)
+                print(parameters)
                 response = self._tls_session.request(http_method, cmd_url,
                                                      params=parameters,
                                                      timeout=utils.TIMEOUT,
@@ -883,7 +885,7 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         # WAF
         self.alertthreshold = service.get('AlertThreshold', None)
         self.intercept = service.get('Intercept', None)
-        if self.alertthreshold is None:
+        if self.alertthreshold is None or int(self.alertthreshold) == 0:
             self._waf = False
         else:
             self._waf = True
